direction_from_rad

Function direction_from_rad 

pub fn direction_from_rad(u: f64, v: f64) -> f64
The direction a wind of east and north components u and v blows from, clockwise from true north, in [0, 2π); 0 for a calm.