pub struct UtcTime { /* private fields */ }Expand description
An instant in Coordinated Universal Time, as seconds since 1970-01-01T00:00:00Z (leap seconds not counted, as in POSIX time).
Implementations
Sourceimpl UtcTime
impl UtcTime
Sourcepub fn from_unix_seconds(seconds: f64) -> Result<Self, Era5Error>
pub fn from_unix_seconds(seconds: f64) -> Result<Self, Era5Error>
Sourcepub fn from_civil(
year: i32,
month: u32,
day: u32,
hour: u32,
minute: u32,
second: f64,
) -> Result<Self, Era5Error>
pub fn from_civil( year: i32, month: u32, day: u32, hour: u32, minute: u32, second: f64, ) -> Result<Self, Era5Error>
The instant at a date and time of the Gregorian calendar, in UTC.
Errors
Era5Error::Domain for a month outside 1 to 12, a day not in the month, an hour past
23, a minute past 59, or a second outside [0, 60).
Sourcepub fn unix_seconds(self) -> f64
pub fn unix_seconds(self) -> f64
Seconds since 1970-01-01T00:00:00Z.