#[non_exhaustive]pub enum VerticalUnit {
Meter,
Foot,
UsSurveyFoot,
}Expand description
The unit a pixel’s value is in, converted to meters by VerticalUnit::meters.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Meter
EPSG 9001. Written before the move to US spelling as Metre, which is still read and never written.
Foot
The international foot, 0.3048 m exactly (EPSG 9002).
UsSurveyFoot
The US survey foot, 1200/3937 m (EPSG 9003).
Implementations