#[non_exhaustive]pub enum Earth {
#[non_exhaustive] Sphere {
radius_m: f64,
},
#[non_exhaustive] Other {
code: u8,
},
}Expand description
The figure of the Earth a grid is defined on (code table 3.2).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]Sphere
A sphere of this radius, m: codes 0 (6,367,470 m), 1 (given), 6 (6,371,229 m) and 8 (6,371,200 m).
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]Other
An oblate spheroid or another figure, by its code; a Lambert grid on it is refused.