#[non_exhaustive]pub struct MaterialRef {
pub name: String,
pub kind: MaterialKind,
pub density: Option<f64>,
}Expand description
The material a part names, with the density its file defines for it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name the part gives.
kind: MaterialKindThe kind the part gives.
density: Option<f64>The density in SI units of its kind, from the first material of that name and kind the
file defines; None if it defines none.
Implementations