#[non_exhaustive]pub struct Motors {
pub configurations: Vec<MotorConfiguration>,
}Expand description
Every motor configuration a .ork design holds.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.configurations: Vec<MotorConfiguration>The configurations: those <rocket> declares in its order, then any only a mount names.
Implementations
Sourceimpl Motors
impl Motors
Sourcepub fn default_configuration(&self) -> Option<&MotorConfiguration>
pub fn default_configuration(&self) -> Option<&MotorConfiguration>
The configuration the file marks as its default, if any.