#[non_exhaustive]pub struct UnreadMotor {
pub at: String,
pub designation: String,
pub inside: String,
pub reason: String,
}Expand description
A <motor> inside a part hpr does not read, such as a pod’s mount.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.at: StringWhere its mount is in the file.
designation: String<designation>.
inside: StringThe tag of the part that was not read: the outermost podset or parallelstage around
the mount, or else the mount’s own tag.
reason: StringWhy its mount was not read, in words.