#[non_exhaustive]pub struct Recovery {
pub devices: Vec<RecoveryDevice>,
pub separations: Vec<StageSeparation>,
pub unread: Vec<UnreadDevice>,
pub unread_separations: Vec<UnreadDevice>,
}Expand description
Every recovery setting in a .ork design.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.devices: Vec<RecoveryDevice>The parachutes and streamers read, in file order.
separations: Vec<StageSeparation>Every stage that states when it separates, in file order.
unread: Vec<UnreadDevice>The parachutes and streamers in parts hpr does not read.
unread_separations: Vec<UnreadDevice>The parallel stages that state a separation, in parts hpr did not read.