#[non_exhaustive]pub struct UnreadDevice {
pub at: String,
pub tag: String,
pub inside: String,
}Expand description
A parachute or streamer inside a part hpr does not read, such as a pod.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.at: StringWhere it is in the file.
tag: Stringparachute or streamer.
inside: StringThe tag of the outermost part that was not read: a podset or parallelstage, or else
the device’s own tag.