#[non_exhaustive]pub enum Atmosphere {
Isa {},
Extended {
temperature_k: Option<f64>,
pressure_pa: Option<f64>,
},
Other {
name: String,
},
}Expand description
The atmosphere a stored simulation was flown in.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Isa
isa: the International Standard Atmosphere.
Extended
extendedisa: the standard atmosphere from a temperature and pressure at the launch site.
Other
A model not listed here, or none, kept by name only.