#[non_exhaustive]pub enum StagingTrigger {
Time {
time_s: f64,
},
Burnout {
mount: String,
delay_s: f64,
},
}Expand description
When a separation fires, in the terms of hpr’s flight triggers
(hpr_sim::recovery::Trigger, which this crate does not depend on).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Time
At a time after launch, s.
Burnout
A delay after the burnout of the motor in a mount (the first tube’s, for a cluster, whose tubes light together).