#[non_exhaustive]pub enum Era5Error {
Show 13 variants
NetCdf(NetCdfError),
MissingVariable {
name: String,
},
Dimensions {
variable: String,
found: Vec<String>,
expected: String,
},
Units {
variable: String,
units: String,
expected: String,
},
Time {
reason: String,
},
OutsideTimes {
requested: f64,
first: f64,
last: f64,
},
OutsideGrid {
axis: &'static str,
value: f64,
first: f64,
last: f64,
},
EmptyAxis {
axis: String,
},
MissingCoordinate {
axis: String,
index: usize,
},
NotMonotonic {
axis: String,
},
MissingValue {
variable: String,
pressure_pa: f64,
},
Domain {
what: &'static str,
value: f64,
},
Atmos(AtmosError),
}Expand description
Why an ERA5 profile could not be read.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NetCdf(NetCdfError)
The netCDF file could not be read.
MissingVariable
A variable the profile needs is not in the file.
Dimensions
A variable’s dimensions are not the ones ERA5 writes.
Fields
Units
A variable’s units are not the ones expected.
Fields
Time
The time variable’s units or calendar cannot be read.
OutsideTimes
The launch time is outside the file’s times.
Fields
OutsideGrid
The site is outside the file’s grid.
Fields
EmptyAxis
A coordinate axis has no values.
MissingCoordinate
A coordinate value is missing (a fill value).
NotMonotonic
A coordinate axis is not strictly monotonic.
MissingValue
A value the profile needs is missing (a fill value) in the file.
Domain
A request value is not usable.
Atmos(AtmosError)
The atmosphere could not be built from the levels.