pub fn element_at<'a>(document: &'a Document, at: &str) -> Option<&'a Element>
The element of document at at, a path as Kept::at writes it, or None when the path does not lead to an element of the name it gives.
document
at
Kept::at
None